aboutsummaryrefslogtreecommitdiffstats
path: root/modules/home.legacy/pkgs
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--modules/home.legacy/pkgs/default.nix128
1 files changed, 15 insertions, 113 deletions
diff --git a/modules/home.legacy/pkgs/default.nix b/modules/home.legacy/pkgs/default.nix
index 1a4c4a1b..ddc633c1 100644
--- a/modules/home.legacy/pkgs/default.nix
+++ b/modules/home.legacy/pkgs/default.nix
@@ -1,70 +1,31 @@
+# nixos-config - My current NixOS configuration
+#
+# Copyright (C) 2025 Benedikt Peetz <benedikt.peetz@b-peetz.de>
+# SPDX-License-Identifier: GPL-3.0-or-later
+#
+# This file is part of my nixos-config.
+#
+# You should have received a copy of the License along with this program.
+# If not, see <https://www.gnu.org/licenses/gpl-3.0.txt>.
{
pkgs,
lib,
- config,
nixosConfig,
...
}:
-# TODO: Remove this whole file, and move each pkgs to a separate module. <2024-11-16>
+# TODO: Remove this whole file, and move each package to a separate module. <2024-11-16>
with pkgs; let
Gui = {
- Terminals = [
- # foot # wayland native terminal
- alacritty # default terminal
- ];
- Browsers = [
- #ungoogled-chromium # web browser (only for web programming)
- #brave
- ];
-
- ImageManipulation = [
- #krita # new, and better (KDE)
- #gimp # conservative, and old (GNOME)
- ];
-
- Social = [
- mumble # voice chat software (client)
- # lutris # multiple game store clients
-
- # nheko # best matrix client (as of today)
- # element-desktop # nheko didn't work
- signal-desktop # to avoid encryption problems with signal-bridge
- ];
-
Misc = [
- #kalzium # Periodic Table of Elements (`element` is [sort of] better)
keepassxc # password manager
- #onlykey # OnlyKey Chrome Desktop App
- anki-bin # spaced repetition
];
};
TuiCli = {
- EyeCandy = [
- #banner # Print large banners to ASCII terminals
- cmatrix # A curses-based scrolling 'Matrix'-like screen
- hyfetch # Neofetch with LGBTQ pride flags.
- ];
-
- Social = [
- iamb # best tui matrix client (as of today)
- ];
-
- Pdfs = [
- con2pdf # Scanner implementation
- ];
-
Misc = [
- android-file-transfer # Android MTP client with minimalistic UI
- #xdg-ninja # A shell script which checks your $HOME for unwanted files and directories.
- xdg-utils # open urls and such things
- yokadi # Command line oriented, sqlite powered, todo list
killall # kill a application by name
- snap-sync-forked # A btrfs based backup solution
bc # Smart calculator
aumo # Automatic mount
- nato # Encodes a string in the standardized spelling alphabet
- virsh-del # Delete a libvirt virtual machine (not really used anymore).
jq # Json parser
];
@@ -75,58 +36,20 @@ with pkgs; let
];
Firefox = [
# `neorg` handles the integration between Firefox profiles and task
# contexts
- (neorg.override
- {
- defaultNeorgProjectDir = config.programs.nixvim.plugins.neorg.settings.load."core.dirman".config.workspaces.projects;
- allProjectsNewline = config.soispha.taskwarrior.projects.projects_newline;
- allProjectsComma = config.soispha.taskwarrior.projects.projects_comma;
- allProjectsPipe = config.soispha.taskwarrior.projects.projects_pipe;
- allWorkspaces = config.programs.nixvim.plugins.neorg.settings.load."core.dirman".config.workspaces;
- xdgConfigHome = config.xdg.configHome;
- xdgDataHome = config.xdg.dataHome;
- })
+ pkgs.tskm
];
};
WM = {
- river = [river]; # A dynamic tiling wayland compositor
-
CLITools = [
- lswt # List Wayland toplevels.
wl-clipboard # Command-line copy/paste utilities.
- swaylock # My current lockscreen implementation.
- ];
-
- Media = [
- wf-recorder # Screen recorder.
- libnotify # a command to send a notification.
- screenshot_persistent # Creates a persisting screenshot.
- screenshot_temporary # Takes a screenshot and stores it in the clipboard.
- ];
- };
-
- Media = {
- View = [
- imv # Image viewer
- zathura # PDF viewer
- ];
-
- YouTube = [
- yti # Wrapper around `yt-dlp`.
- yt # A command line YouTube client
- ];
-
- Listen = [
- spodi # Wrapper around `spotdl`.
- sort_song # Sorts songs in the current directory.
];
};
Hardware = {
Storage = [
- #compsize # Calculate compression ratio of a set of files on Btrfs
# TODO: smartmontools # Control and monitor S.M.A.R.T. enabled ATA and SCSI Hard Drives
];
@@ -144,48 +67,27 @@ with pkgs; let
backlightName = nixosConfig.soispha.laptop.backlight;
}
);
-
- Input = [
- #piper # GTK application to configure gaming mice
- ];
};
SystemUpdate = [
fupdate # Generic update tool.
- update-sys # System update tool (meant to slot into `fupdate`).
+ fupdate-sys # System update tool (meant to slot into `fupdate`).
+ fupdate-flake # Nix flake update tool (meant to slot into `fupdate`).
];
FileListers = [
tree # A directory listing program displaying a depth indented list of files
fd # Simple, fast and user-friendly alternative to find
ripgrep # A search tool that combines the usability of ag with the raw speed of grep
- fzf # used to quickly move around with its keybindings
file # Show information about a file
- ll # Wrapper around `lf` to automatically change the path
- lm # Wrapper around `ll` to automatically cd to the last accessed path
- ];
-
- Editors = [
- ed # A POSIX-compliant line-oriented text editor
- #sed # GNU stream editor
- vim # The original ex/vi text editor (this is `vim` and not `vi`, as `vi` is unfree)
- #neovim # Fork of Vim aiming to improve user experience, plugins, and GUIs
];
Programming = {
GeneralTools = [
- stamp # Add a license header to a file
- git # the fast distributed version control system
- git-absorb # git commit --fixup, but automatic
- git-edit-index # Allows you to edit the indexed version of a file
- git-cm # A wrapper that re-adds the last commit's subject
- git-cleanup # An automatic merged branch deleter
glow # Command-line markdown renderer
];
};
};
- # TODO: unmaintained, find sth else:
- # handlr # Powerful alternative to xdg-utils written in Rust
mapFun = x:
if builtins.isAttrs x
then
@@ -194,7 +96,7 @@ with pkgs; let
else builtins.attrValues x
else [x];
in {
- home.packages =
+ config.home.packages =
[]
++ (with builtins;
concatLists
@@ -75,58 +36,20 @@ with pkgs; let
];
Firefox = [
- # `neorg` handles the integration between Firefox profiles and task
+ # `tskm` handles the integration between Firefox profiles and task
# contexts